# Please keep this package in sync with FC

# (tv) mga doesn't have AppIndicator3 and Vte is 2.91 (which aslo required by v-m):
%global __requires_exclude typelib\\\(AppIndicator3\\\)|typelib\\\(Vte\\\) = 2.90

# -*- rpm-spec -*-

%global default_hvs                "qemu,xen,lxc"


# End local config

%define subrel 2

Name: virt-manager
Version: 3.2.0
Release: %mkrel 2
%global verrel %{version}-%{release}
Summary: Desktop tool for managing virtual machines via libvirt
Group: Graphical desktop/GNOME
License: GPLv2+
BuildArch: noarch
URL: https://virt-manager.org/
Source0: https://virt-manager.org/download/sources/%{name}/%{name}-%{version}.tar.gz

# Fix 'domain not found' race (bz #1901081)
Patch0001: 0001-virtinst-Fix-TOCTOU-in-domain-enumeration.patch


Requires: virt-manager-common = %{verrel}
Requires: python3-gobject3
Requires: typelib(Gtk) = 3.0
Requires: typelib(GtkVnc) = 2.0
# FC has Requires: libvirt-glib >= 0.0.9, which covered by autoreq on 'typelib(LibvirtGLib) '
Requires: typelib(SpiceClientGtk) = 3.0
Requires: spice-gtk

# We can work with gtksourceview 3 or gtksourceview4, pick the latest one
# we automatically got deps on both, so let's drop the old one
%global __requires_exclude %{?__requires_exclude:%__requires_exclude|}typelib\\\(GtkSource\\\) = 3.0

# virt-manager is one of those apps that people will often install onto
# a headless machine for use over SSH. This means the virt-manager dep
# chain needs to provide everything we need to get a usable app experience.
# Unfortunately nothing in our chain has an explicit dep on some kind
# of usable gsettings back-end, so we explicitly depend on dconf so that
# user settings actually persist across app runs.
Requires: dconf
 
# The vte291 package is actually the latest vte with API version 2.91, while
# the vte3 package is effectively a compat package with API version 2.90.
# virt-manager works fine with either, so pull the latest bits so there's
# no ambiguity.
%global __requires_exclude %{?__requires_exclude:%__requires_exclude|}typelib\\\(Vte\\\) = 2.90

# Weak dependencies for the common virt-manager usecase
Requires: libvirt-utils

# Optional inspection of guests
Suggests: python3-libguestfs

BuildRequires: gettext
BuildRequires: pkgconfig(python3)
BuildRequires: python3-docutils
 

%description
Virtual Machine Manager provides a graphical tool for administering virtual
machines for KVM, Xen, and LXC. Start, stop, add or remove virtual devices,
connect to a graphical or serial console, and see resource usage statistics
for existing VMs on local or remote machines. Uses libvirt as the back-end
management API.


%package common
Summary: Common files used by the different Virtual Machine Manager interfaces
Group:    Emulators

Requires: python3-argcomplete
Requires: python3-libvirt
Requires: python3-libxml2
Requires: python3-requests
# Required for gobject-introspection infrastructure
Requires: python3-gobject3
# Required for pulling files from iso media with isoinfo
Requires: genisoimage

%description common
Common files used by the different virt-manager interfaces, as well as
virt-install related tools.

%package -n virt-install
Summary: Utilities for installing virtual machines
Group:    Emulators
Requires: virt-manager-common = %{verrel}
# For 'virsh console'
Requires: libvirt-client

Provides: virt-install
Provides: virt-clone
Provides: virt-xml

%description -n virt-install
Package includes several command line utilities, including virt-install
(build and install new VMs) and virt-clone (clone an existing virtual
machine).


%prep
%setup -q


%build
%if %{default_hvs}
%global _default_hvs --default-hvs %{default_hvs}
%endif

./setup.py configure \
    %{?_default_hvs}


%install
./setup.py \
    --no-update-icon-cache --no-compile-schemas \
    install -O1 --root=%{buildroot}
%find_lang %{name}

%if 0%{?py_byte_compile:0}
# https://docs.fedoraproject.org/en-US/packaging-guidelines/Python_Appendix/#manual-bytecompilation
%py_byte_compile %{python3} %{buildroot}%{_datadir}/virt-manager/
%endif

# Replace '#!/usr/bin/env python3' with '#!/usr/bin/python3'
# The format is ideal for upstream, but not a distro. See:
# https://fedoraproject.org/wiki/Features/SystemPythonExecutablesUseSystemPython
for f in $(find %{buildroot} -type f -executable -print); do
    sed -i "1 s|^#!/usr/bin/env python3|#!%{__python3}|" $f || :
done

%files
%doc README.md COPYING NEWS.md
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1*
%{_datadir}/%{name}/ui/*.ui
%{_datadir}/%{name}/virtManager

%{_datadir}/%{name}/icons
%{_datadir}/icons/hicolor/*/apps/*

%{_datadir}/applications/%{name}.desktop
%{_datadir}/glib-2.0/schemas/org.virt-manager.virt-manager.gschema.xml
%{_datadir}/metainfo/%{name}.appdata.xml

%files common -f %{name}.lang
%dir %{_datadir}/%{name}

%{_datadir}/%{name}/virtinst

%files -n virt-install
%{_mandir}/man1/virt-install.1*
%{_mandir}/man1/virt-clone.1*
%{_mandir}/man1/virt-xml.1*

%{_datadir}/bash-completion/completions/virt-install
%{_datadir}/bash-completion/completions/virt-clone
%{_datadir}/bash-completion/completions/virt-xml

%{_bindir}/virt-install
%{_bindir}/virt-clone
%{_bindir}/virt-xml



%changelog
* Sun Apr 24 2022 ghibo <ghibo> 3.2.0-2.2.mga8
+ Revision: 1853037
- Rebuild against recompiled libvirt
- Rebuild against upgraded xen.
- Merge typo fixes to spec file from cauldron.

* Wed Jan 20 2021 tv <tv> 3.2.0-2.mga8
+ Revision: 1672614
- Fix 'domain not found' race (rhbz#1901081)

* Sun Nov 15 2020 tv <tv> 3.2.0-1.mga8
+ Revision: 1646382
- 3.2.0

* Thu Oct 01 2020 tv <tv> 3.1.0-1.mga8
+ Revision: 1631401
- Update to version 3.1.0

* Wed Sep 16 2020 tv <tv> 3.0.0-1.mga8
+ Revision: 1626923
- require dconf for when installed on headless machine for use over SSH
- drop autoreq on gtksourceview3 as we also got one on gtksourceview4
- Update to version 3.0.0
- Drop pre-mga7 conflicts

* Sat Feb 15 2020 umeabot <umeabot> 2.2.1-2.mga8
+ Revision: 1526860
- Mageia 8 Mass Rebuild

* Thu Jul 04 2019 tv <tv> 2.2.1-1.mga8
+ Revision: 1418407
- Rebased to version 2.2.1 (CVE-2019-10183: Replace --unattended user-password
  and admin-password with user-password-file and admin-password-file)

* Mon Jul 01 2019 tv <tv> 2.2.0-1.mga8
+ Revision: 1416766
- BR typelib(Libosinfo)
- BR python3-gobject3
- new release

* Thu Apr 04 2019 tv <tv> 2.1.0-2.mga7
+ Revision: 1385774
- Fix --initrd-inject with f30 URLs (rhbz#1686464)

* Tue Feb 05 2019 tv <tv> 2.1.0-1.mga7
+ Revision: 1363304
- new release

* Wed Oct 17 2018 tv <tv> 2.0.0-1.mga7
+ Revision: 1321254
- version 2.0.0
  o Finish port to Python 3
  o Improved VM defaults: q35 PCIe, usb3, CPU host-model
  o Search based OS selection UI for new VMs
  o Track OS name for lifetime of domain in <metadata> XML
  o Host interface management UI has been completely removed
  o Show domain IP on interface details page

* Mon Sep 24 2018 tv <tv> 1.6.0-0.4.git3bc7ff24c.mga7
+ Revision: 1303411
- do byte compile python3 now that rpm-mageia-setup is fixed

* Mon Sep 10 2018 tv <tv> 1.6.0-0.3.git3bc7ff24c.mga7
+ Revision: 1258169
- Enable arm32+uefi (rhbz#1613996)

* Tue Sep 04 2018 tv <tv> 1.6.0-0.2.git3bc7ff24c.mga7
+ Revision: 1257141
- do not abort build on bytecompilation errors
- filter out older typelib(Vte) requires (both old/new are automatically emitted)
- require vte 2.91

* Sun May 06 2018 tv <tv> 1.6.0-0.1.git3bc7ff24c.mga7
+ Revision: 1226628
- Update to latest git snapshot, contains python3 port
- drop no more needed patch

* Sat Mar 03 2018 tv <tv> 1.5.1-1.mga7
+ Revision: 1206386
- new release

* Wed Feb 07 2018 tv <tv> 1.5.0-1.mga7
+ Revision: 1199575
- drop fix-full-screen-keys-menu patch
- new release
- new release
- Fix 'Add Hardware' wizard for non-x86 guests (rhbz#1505532)

* Wed Sep 20 2017 tv <tv> 1.4.3-1.mga7
+ Revision: 1156309
- new release

* Tue Sep 05 2017 tv <tv> 1.4.2-1.mga7
+ Revision: 1151294
- new release

* Sun Mar 26 2017 tv <tv> 1.4.1-1.mga6
+ Revision: 1094870
- new release

* Thu Dec 22 2016 tv <tv> 1.4.0-4.mga6
+ Revision: 1076481
- Fix version check for spice GL support
- Don't return virtio1.0-net as a valid device name (rhbz#1399083)
- Fix window size tracking on wayland (rhbz#1375175)
- Fix 'resize to VM' on wayland (rhbz#1397598)
- Fix fedora24 installs from incorrectly using virtio-input (rhbz#1391522)
- Fix error checking extra_args for console argument

* Sun Jul 03 2016 cjw <cjw> 1.4.0-3.mga6
+ Revision: 1038561
- rediff patch to fix full-screen send-key menu behavior
- add a quick fix to allow mga4+ netinstalls

* Thu Jun 30 2016 tv <tv> 1.4.0-2.mga6
+ Revision: 1038183
- Fix italian translation from breaking the app (rhbz#1350185)

* Mon Jun 20 2016 tv <tv> 1.4.0-1.mga6
+ Revision: 1036878
- new release

* Mon May 23 2016 tv <tv> 1.3.2-9.20160520git2204de62d9.mga6
+ Revision: 1018107
- rebase to latest git: update viewer to work with spice GL
- fix conflicts for smooth upgrades

* Wed Apr 27 2016 neoclust <neoclust> 1.3.2-7.mga6
+ Revision: 1006866
- Add conflict to ease upgrade

* Tue Apr 26 2016 tv <tv> 1.3.2-6.mga6
+ Revision: 1006541
- wanted package is qemu-kvm instead of qemu

* Mon Apr 25 2016 tv <tv> 1.3.2-5.mga6
+ Revision: 1006127
- fix detecting Mageia when passing a remote URL:

* Thu Apr 21 2016 tv <tv> 1.3.2-4.mga6
+ Revision: 1004040
- do not use stable defaults
- kill old GConf conversion script
- split out virt-install pkg for non X11 servers

* Thu Apr 21 2016 tv <tv> 1.3.2-3.mga6
+ Revision: 1003985
- fix screenshot on cauldron/mga6 (rhbz#1297988)
- fix URL installs when content-length header missing (rhbz#1297900)

* Thu Apr 21 2016 tv <tv> 1.3.2-2.mga6
+ Revision: 1003979
- requires libvirt-utils

* Fri Mar 04 2016 oden <oden> 1.3.2-1.mga6
+ Revision: 985667
- 1.3.2

* Sun Jan 17 2016 wally <wally> 1.3.0-2.mga6
+ Revision: 925093
- rebuild to get more typelib() requires
- drop unneeded libgirepository-devel BR

* Sun Nov 29 2015 oden <oden> 1.3.0-1.mga6
+ Revision: 907046
- 1.3.0

* Mon Nov 16 2015 cjw <cjw> 1.2.1-2.mga6
+ Revision: 903660
- rediff patch1

* Tue Oct 27 2015 ycantin <ycantin> 1.2.1-1.mga6
+ Revision: 895779
- new version 1.2.1

* Sat Jun 20 2015 tv <tv> 1.2.0-1.mga6
+ Revision: 835801
- new release

* Wed Nov 19 2014 cjw <cjw> 1.1.0-7.mga5
+ Revision: 797801
- patch1: fix behavior of full screen send-key-combo menu

* Tue Oct 21 2014 oden <oden> 1.1.0-6.mga5
+ Revision: 792311
- fix deps

* Sun Oct 19 2014 cjw <cjw> 1.1.0-5.mga5
+ Revision: 791763
- rebuild to add missing typelib(LibvirtGLib) dependency

* Wed Oct 15 2014 umeabot <umeabot> 1.1.0-4.mga5
+ Revision: 739438
- Second Mageia 5 Mass Rebuild

* Thu Oct 09 2014 tv <tv> 1.1.0-3.mga5
+ Revision: 737724
- rebuild in order to pick up typelib() deps

* Tue Sep 16 2014 umeabot <umeabot> 1.1.0-2.mga5
+ Revision: 690213
- Mageia 5 Mass Rebuild
+ tv <tv>
- use %%global for req/prov exclude
- autoconvert to new prov/req excludes
+ ovitters <ovitters>
- add gobject-introspection BR for typelib auto BR

* Mon Sep 08 2014 tv <tv> 1.1.0-1.mga5
+ Revision: 673705
- new release

* Fri Jun 06 2014 tv <tv> 1.0.1-3.mga5
+ Revision: 633908
- requires spice-gtk for spice-client-glib-usb-acl-helper (in order to be able to attach USB devices)

* Wed Jun 04 2014 fwang <fwang> 1.0.1-2.mga5
+ Revision: 632813
- rebuild for new vte

* Mon Mar 24 2014 oden <oden> 1.0.1-1.mga5
+ Revision: 607831
- 1.0.1

* Mon Feb 17 2014 oden <oden> 1.0.0-1.mga5
+ Revision: 593537
- 1.0.0

* Fri Jan 24 2014 oden <oden> 0.10.0-12.git1ffcc0cc.1.mga4
+ Revision: 567702
- sync with virt-manager-0.10.0-5.git1ffcc0cc.fc21.src.rpm

* Thu Nov 07 2013 oden <oden> 0.10.0-11.git79196cdf.1.mga4
+ Revision: 549880
- bump release
- sync with fedora, use git79196cdf that actually works
- drop the mbs patch, it's fixed upstream

* Sat Nov 02 2013 fwang <fwang> 0.10.0-10.mga4
+ Revision: 549033
- requires python-gi

* Mon Oct 21 2013 umeabot <umeabot> 0.10.0-9.mga4
+ Revision: 536982
- Mageia 4 Mass Rebuild

* Wed Sep 25 2013 oden <oden> 0.10.0-8.mga4
+ Revision: 486060
- P0: add the Mandriva mbs1 product

* Wed Jul 31 2013 wally <wally> 0.10.0-7.mga4
+ Revision: 461852
- rebuild with new rpm-mageia-setup to find typelib requires from python scripts without .py extension (mga#10863)

* Sun Jul 21 2013 fwang <fwang> 0.10.0-6.mga4
+ Revision: 456863
- python-virtinst merged into virt-manager

* Sun Jul 21 2013 fwang <fwang> 0.10.0-5.mga4
+ Revision: 456825
- fix typo

* Sun Jul 21 2013 fwang <fwang> 0.10.0-4.mga4
+ Revision: 456824
- add requires exception on indicator

* Sun Jul 21 2013 fwang <fwang> 0.10.0-3.mga4
+ Revision: 456817
- fix typo

* Sun Jul 21 2013 fwang <fwang> 0.10.0-2.mga4
+ Revision: 456816
- add some configure switches
- add some configure switches

* Sun Jul 21 2013 fwang <fwang> 0.10.0-1.mga4
+ Revision: 456810
- new version 0.10.0

* Mon Apr 15 2013 kharec <kharec> 0.9.5-2.mga3
+ Revision: 410148
- fix version in requires to fix #9740

* Fri Apr 12 2013 kharec <kharec> 0.9.5-1.mga3
+ Revision: 409803
- new version 0.9.5 (bugfixes)

* Mon Jan 14 2013 umeabot <umeabot> 0.9.4-4.mga3
+ Revision: 385422
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Jan 08 2013 fwang <fwang> 0.9.4-3.mga3
+ Revision: 341559
- update file list

* Sun Dec 23 2012 cjw <cjw> 0.9.4-2.mga3
+ Revision: 334089
- add dependency on python-spice-client-gtk for spice display connections

* Thu Oct 18 2012 tv <tv> 0.9.4-1.mga3
+ Revision: 307932
- new release
- new release

* Mon Oct 15 2012 blino <blino> 0.9.3-2.mga3
+ Revision: 306479
- require acl for the getfacl command used in VirtualDisk.py

* Fri Jul 13 2012 tv <tv> 0.9.3-1.mga3
+ Revision: 270656
- new release

* Tue May 15 2012 ennael <ennael> 0.9.1-2.mga2
+ Revision: 235729
- add missing require gettext

* Fri Mar 02 2012 misc <misc> 0.9.1-1.mga2
+ Revision: 216639
- new version 0.9.1
+ fwang <fwang>
- fix post script
+ tv <tv>
- fix file list
- new release

* Thu Apr 14 2011 tv <tv> 0.8.7-1.mga1
+ Revision: 84874
- new release

* Mon Mar 07 2011 saispo <saispo> 0.8.6-1.mga1
+ Revision: 66076
- imported package virt-manager

